def UpperName(name):
  newname = ""
  splitName = name.split(" ")
  for name in splitName:
    newname += name.capatalize() + " "
  return newname[1:]